package com.hw.mes.mapper;

import java.util.List;
import com.hw.mes.domain.MesBaseMaterialType;

/**
 * 物料类型信息Mapper接口
 * 
 * @author Yinq
 * @date 2024-01-23
 */
public interface MesBaseMaterialTypeMapper 
{
    /**
     * 查询物料类型信息
     * 
     * @param matrialTypeId 物料类型信息主键
     * @return 物料类型信息
     */
    public MesBaseMaterialType selectMesBaseMaterialTypeByMatrialTypeId(Long matrialTypeId);

    /**
     * 查询物料类型信息列表
     * 
     * @param mesBaseMaterialType 物料类型信息
     * @return 物料类型信息集合
     */
    public List<MesBaseMaterialType> selectMesBaseMaterialTypeList(MesBaseMaterialType mesBaseMaterialType);

    /**
     * 新增物料类型信息
     * 
     * @param mesBaseMaterialType 物料类型信息
     * @return 结果
     */
    public int insertMesBaseMaterialType(MesBaseMaterialType mesBaseMaterialType);

    /**
     * 修改物料类型信息
     * 
     * @param mesBaseMaterialType 物料类型信息
     * @return 结果
     */
    public int updateMesBaseMaterialType(MesBaseMaterialType mesBaseMaterialType);

    /**
     * 删除物料类型信息
     * 
     * @param matrialTypeId 物料类型信息主键
     * @return 结果
     */
    public int deleteMesBaseMaterialTypeByMatrialTypeId(Long matrialTypeId);

    /**
     * 批量删除物料类型信息
     * 
     * @param matrialTypeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMesBaseMaterialTypeByMatrialTypeIds(Long[] matrialTypeIds);
}
